aboutsummaryrefslogtreecommitdiff
path: root/src/Text/Pandoc/Writers/Ms.hs
diff options
context:
space:
mode:
authorJohn MacFarlane <jgm@berkeley.edu>2018-11-01 16:46:43 -0700
committerJohn MacFarlane <jgm@berkeley.edu>2018-11-01 16:46:43 -0700
commite10d5b3d5bc4de124549762b1523575c7824ca28 (patch)
tree499293e700253e812afe87f6c5d758b35c43fc5b /src/Text/Pandoc/Writers/Ms.hs
parent26341c163225c142d19af425af08049cb2eef446 (diff)
downloadpandoc-e10d5b3d5bc4de124549762b1523575c7824ca28.tar.gz
Change 'groff' -> 'roff'.
These formats (man, ms) are not groff-specific.
Diffstat (limited to 'src/Text/Pandoc/Writers/Ms.hs')
-rw-r--r--src/Text/Pandoc/Writers/Ms.hs8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/Text/Pandoc/Writers/Ms.hs b/src/Text/Pandoc/Writers/Ms.hs
index 6abc4bf93..202cb91ad 100644
--- a/src/Text/Pandoc/Writers/Ms.hs
+++ b/src/Text/Pandoc/Writers/Ms.hs
@@ -26,7 +26,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
Stability : alpha
Portability : portable
-Conversion of 'Pandoc' documents to groff ms format.
+Conversion of 'Pandoc' documents to roff ms format.
TODO:
@@ -69,7 +69,7 @@ writeMs :: PandocMonad m => WriterOptions -> Pandoc -> m Text
writeMs opts document =
evalStateT (pandocToMs opts document) defaultWriterState
--- | Return groff ms representation of document.
+-- | Return roff ms representation of document.
pandocToMs :: PandocMonad m => WriterOptions -> Pandoc -> MS m Text
pandocToMs opts (Pandoc meta blocks) = do
let colwidth = if writerWrapText opts == WrapAuto
@@ -123,7 +123,7 @@ toSmallCaps opts (c:cs)
| otherwise = escapeStr opts [c] ++ toSmallCaps opts cs
-- We split inline lists into sentences, and print one sentence per
--- line. groff/troff treats the line-ending period differently.
+-- line. roff treats the line-ending period differently.
-- See http://code.google.com/p/pandoc/issues/detail?id=148.
blockToMs :: PandocMonad m
@@ -372,7 +372,7 @@ inlineToMs opts (Strong lst) =
inlineToMs opts (Strikeout lst) = do
contents <- inlineListToMs opts lst
-- we use grey color instead of strikeout, which seems quite
- -- hard to do in groff for arbitrary bits of text
+ -- hard to do in roff for arbitrary bits of text
return $ text "\\m[strikecolor]" <> contents <> text "\\m[]"
inlineToMs opts (Superscript lst) = do
contents <- inlineListToMs opts lst